pub trait Decoding<T = [u8]>where
T: ?Sized,{
type Repr: Default + AsMut<T>;
// Required method
fn decode(buf: Self::Repr) -> Self;
}Expand description
The interface for all types that can be turned into verifier messages.
Required Associated Types
Required Methods
Sourcefn decode(buf: Self::Repr) -> Self
fn decode(buf: Self::Repr) -> Self
The distribution-preserving map, that re-maps a squeezed output Decoding::Repr into a verifier message.
This map is not exactly a decoding function (e.g., it can be onto). What is demanded from this function is that
it preserves the uniform distribution: if Decoding::Repr is distributed uniformly at random, the also the output of decode is so.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.
Implementations on Foreign Types
Sourceimpl Decoding for RistrettoPoint
Available on crate feature curve25519-dalek only.
impl Decoding for RistrettoPoint
Available on crate feature
curve25519-dalek only.Sourceimpl Decoding for Mersenne31
Available on crate feature p3-mersenne-31 only.
impl Decoding for Mersenne31
Available on crate feature
p3-mersenne-31 only.Sourceimpl<C: Fp2Config> Decoding for Fp2<C>
Available on crate feature ark-ff only.
impl<C: Fp2Config> Decoding for Fp2<C>
Available on crate feature
ark-ff only.type Repr = DecodingFieldBuffer<QuadExtField<Fp2ConfigWrapper<C>>>
fn decode(repr: Self::Repr) -> Self
Sourceimpl<C: Fp3Config> Decoding for Fp3<C>
Available on crate feature ark-ff only.
impl<C: Fp3Config> Decoding for Fp3<C>
Available on crate feature
ark-ff only.type Repr = DecodingFieldBuffer<CubicExtField<Fp3ConfigWrapper<C>>>
fn decode(repr: Self::Repr) -> Self
Sourceimpl<C: Fp4Config> Decoding for Fp4<C>
Available on crate feature ark-ff only.
impl<C: Fp4Config> Decoding for Fp4<C>
Available on crate feature
ark-ff only.type Repr = DecodingFieldBuffer<QuadExtField<Fp4ConfigWrapper<C>>>
fn decode(repr: Self::Repr) -> Self
Sourceimpl<C: Fp6Config> Decoding for Fp6<C>
Available on crate feature ark-ff only.
impl<C: Fp6Config> Decoding for Fp6<C>
Available on crate feature
ark-ff only.type Repr = DecodingFieldBuffer<CubicExtField<Fp6ConfigWrapper<C>>>
fn decode(repr: Self::Repr) -> Self
Sourceimpl<C: Fp12Config> Decoding for Fp12<C>
Available on crate feature ark-ff only.
impl<C: Fp12Config> Decoding for Fp12<C>
Available on crate feature
ark-ff only.type Repr = DecodingFieldBuffer<QuadExtField<Fp12ConfigWrapper<C>>>
fn decode(repr: Self::Repr) -> Self
Sourceimpl<C: FpConfig<N>, const N: usize> Decoding for Fp<C, N>
Available on crate feature ark-ff only.
impl<C: FpConfig<N>, const N: usize> Decoding for Fp<C, N>
Available on crate feature
ark-ff only.