pub trait Decoding<T = [u8]>where
T: ?Sized,{
type Repr: Default + AsMut<T>;
// Required method
fn decode(buf: Self::Repr) -> Self;
}Expand description
The interface for all types that can be turned into verifier messages.
Required Associated Types
Required Methods
Sourcefn decode(buf: Self::Repr) -> Self
fn decode(buf: Self::Repr) -> Self
The distribution-preserving map, that re-maps a squeezed output Decoding::Repr into a verifier message.
This map is not exactly a decoding function (e.g., it can be onto). What is demanded from this function is that
it preserves the uniform distribution: if Decoding::Repr is distributed uniformly at random, the also the output of decode is so.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.